@@ -255,8 +255,14 @@ gpm_button_class_init (GpmButtonClass *klass)
 gboolean
 gpm_button_is_lid_closed (GpmButton *button)
 {
+	gboolean lid_is_closed;
+
 	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
-	return button->priv->lid_is_closed;
+
+	g_object_get (button->priv->client,
+		      "lid-is-closed", &lid_is_closed,
+		      NULL);
+	return lid_is_closed;
 }
 
 /**
@@ -324,7 +330,11 @@ gpm_button_init (GpmButton *button)
 	/* register the brightness keys */
 	gpm_button_xevent_key (button, XF86XK_PowerOff, GPM_BUTTON_POWER);
 #ifdef HAVE_XF86XK_SUSPEND
-	gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_SUSPEND);
+	/* The kernel messes up suspend/hibernate in some places. One of
+	 * them is the key names. Unfortunately, they refuse to see the
+	 * errors of their way in the name of 'compatibility'. Meh
+	 */
+	gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_HIBERNATE);
 #endif
 	gpm_button_xevent_key (button, XF86XK_Sleep, GPM_BUTTON_SUSPEND); /* should be configurable */
 #ifdef HAVE_XF86XK_HIBERNATE
