@@ -27,6 +27,8 @@
 #include "egg-test.h"
 #include "egg-debug.h"
 
+#include "gpm-screensaver.h"
+
 /* prototypes */
 void egg_precision_test (EggTest *test);
 void egg_discrete_test (EggTest *test);
@@ -35,14 +37,11 @@ void egg_array_float_test (EggTest *test);
 void egg_idletime_test (EggTest *test);
 
 void gpm_common_test (EggTest *test);
-void gpm_cell_unit_test (EggTest *test);
-void gpm_cell_test (EggTest *test);
-void gpm_cell_test_array (EggTest *test);
-void gpm_inhibit_test (EggTest *test);
+void gpm_idle_test (EggTest *test);
 void gpm_phone_test (EggTest *test);
+void gpm_dpms_test (EggTest *test);
 void gpm_graph_widget_test (EggTest *test);
 void gpm_proxy_test (EggTest *test);
-void gpm_hal_device_power_test (EggTest *test);
 void gpm_hal_manager_test (EggTest *test);
 void gpm_device_test (EggTest *test);
 void gpm_device_teststore (EggTest *test);
@@ -59,6 +58,8 @@ main (int argc, char **argv)
 	/* needed for DPMS checks */
 	gtk_init (&argc, &argv);
 
+	gpm_screensaver_test (test);
+
 	/* tests go here */
 	egg_precision_test (test);
 	egg_discrete_test (test);
@@ -67,13 +68,13 @@ main (int argc, char **argv)
 //	egg_idletime_test (test);
 
 	gpm_common_test (test);
-	gpm_inhibit_test (test);
+	gpm_idle_test (test);
 	gpm_phone_test (test);
+//	gpm_dpms_test (test);
 //	gpm_graph_widget_test (test);
 
 #if 0
 	gpm_proxy_test (test);
-	gpm_hal_device_power_test (test);
 	gpm_hal_manager_test (test);
 	gpm_device_test (test);
 	gpm_device_teststore (test);
